==> qt6-wayland-6.1.0beta1-1-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6WaylandClient/Qt6QWaylandWlShellIntegrationPluginDependencies.cmake <==
set(QWaylandWlShellIntegrationPlugin_FOUND FALSE)

# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(_third_party_deps "Wayland\;FALSE\;1.15\;")

foreach(_target_dep ${_third_party_deps})
    list(GET _target_dep 0 pkg)
    list(GET _target_dep 1 is_optional)
    list(GET _target_dep 2 version)
    list(GET _target_dep 3 components)
    set(find_package_args "${pkg}")
    if(version)
        list(APPEND find_package_args "${version}")
    endif()
    if(components)
        string(REPLACE " " ";" components "${components}")
        list(APPEND find_package_args COMPONENTS ${components})
    endif()

    if(is_optional)
        if(${CMAKE_FIND_PACKAGE_NAME}_FIND_QUIETLY)
            list(APPEND find_package_args QUIET)
        endif()
        find_package(${find_package_args})
    else()
        find_dependency(${find_package_args})
    endif()
endforeach()

set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(_target_deps "Qt6Core\;6.1.0;Qt6Gui\;6.1.0;Qt6WaylandClient\;6.1.0")
foreach(_target_dep ${_target_deps})
    list(GET _target_dep 0 pkg)
    list(GET _target_dep 1 version)

    if (NOT ${pkg}_FOUND)
        find_dependency(${pkg} ${version}
            PATHS
                ${CMAKE_CURRENT_LIST_DIR}/..
                ${QT_ADDITIONAL_PACKAGES_PREFIX_PATH}
                ${QT_EXAMPLES_CMAKE_PREFIX_PATH}
            ${__qt_use_no_default_path_for_qt_packages}
        )
    endif()
endforeach()

set(QWaylandWlShellIntegrationPlugin_FOUND TRUE)

==> qt6-wayland-6.2.0beta1-1-x86_64.pkg.tar.zst: usr/lib/cmake/Qt6WaylandClient/Qt6QWaylandWlShellIntegrationPluginDependencies.cmake <==
set(QWaylandWlShellIntegrationPlugin_FOUND FALSE)

# note: _third_party_deps example: "ICU\\;FALSE\\;1.0\\;i18n uc data;ZLIB\\;FALSE\\;\\;"
set(_third_party_deps "")

foreach(_target_dep ${_third_party_deps})
    list(GET _target_dep 0 pkg)
    list(GET _target_dep 1 is_optional)
    list(GET _target_dep 2 version)
    list(GET _target_dep 3 components)
    list(GET _target_dep 4 optional_components)
    set(find_package_args "${pkg}")
    if(version)
        list(APPEND find_package_args "${version}")
    endif()
    if(components)
        string(REPLACE " " ";" components "${components}")
        list(APPEND find_package_args COMPONENTS ${components})
    endif()
    if(optional_components)
        string(REPLACE " " ";" optional_components "${optional_components}")
        list(APPEND find_package_args OPTIONAL_COMPONENTS ${optional_components})
    endif()

    if(is_optional)
        if(${CMAKE_FIND_PACKAGE_NAME}_FIND_QUIETLY)
            list(APPEND find_package_args QUIET)
        endif()
        find_package(${find_package_args})
    else()
        find_dependency(${find_package_args})
    endif()
endforeach()

set(__qt_use_no_default_path_for_qt_packages "NO_DEFAULT_PATH")
if(QT_DISABLE_NO_DEFAULT_PATH_IN_QT_PACKAGES)
    set(__qt_use_no_default_path_for_qt_packages "")
endif()

# note: target_deps example: "Qt6Core\;5.12.0;Qt6Gui\;5.12.0"
set(_QWaylandWlShellIntegrationPlugin_target_deps "Qt6GuiPrivate\;6.2.0;Qt6WaylandClientPrivate\;6.2.0;Qt6WlShellIntegrationPrivate\;6.2.0")
set(_QWaylandWlShellIntegrationPlugin_find_dependency_paths "${CMAKE_CURRENT_LIST_DIR}/..")
_qt_internal_find_dependencies(_QWaylandWlShellIntegrationPlugin_target_deps _QWaylandWlShellIntegrationPlugin_find_dependency_paths)

set(QWaylandWlShellIntegrationPlugin_FOUND TRUE)
